@@ -1,11 +1,12 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015-2022 Mike Fährmann
+# Copyright 2015-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 
+import sys
 import re
 
 modules = [
@@ -34,6 +35,7 @@ modules = [
     "desktopography",
     "deviantart",
     "dynastyscans",
+    "e621",
     "erome",
     "exhentai",
     "fallenangels",
@@ -72,6 +74,7 @@ modules = [
     "instagram",
     "issuu",
     "itaku",
+    "itchio",
     "kabeuchi",
     "keenspot",
     "kemonoparty",
@@ -91,7 +94,7 @@ modules = [
     "mangapark",
     "mangasee",
     "mangoxo",
-    "mememuseum",
+    "misskey",
     "myhentaigallery",
     "myportfolio",
     "nana",
@@ -118,6 +121,7 @@ modules = [
     "plurk",
     "poipiku",
     "pornhub",
+    "pornpics",
     "pururin",
     "reactor",
     "readcomiconline",
@@ -129,6 +133,7 @@ modules = [
     "seiga",
     "senmanga",
     "sexcom",
+    "shimmie2",
     "simplyhentai",
     "skeb",
     "slickpic",
@@ -137,6 +142,7 @@ modules = [
     "soundgasm",
     "speakerdeck",
     "subscribestar",
+    "szurubooru",
     "tapas",
     "tcbscans",
     "telegraph",
@@ -148,8 +154,10 @@ modules = [
     "twitter",
     "unsplash",
     "uploadir",
+    "urlshortener",
     "vanillarock",
     "vichan",
+    "vipergirls",
     "vk",
     "vsco",
     "wallhaven",
@@ -217,20 +225,33 @@ def extractors():
 # --------------------------------------------------------------------
 # internals
 
-_cache = []
-_module_iter = iter(modules)
-
 
 def _list_classes():
-    """Yield all available extractor classes"""
+    """Yield available extractor classes"""
     yield from _cache
 
-    globals_ = globals()
-    for module_name in _module_iter:
-        module = __import__(module_name, globals_, None, (), 1)
+    for module in _module_iter:
         yield from add_module(module)
 
-    globals_["_list_classes"] = lambda : _cache
+    globals()["_list_classes"] = lambda : _cache
+
+
+def _modules_internal():
+    globals_ = globals()
+    for module_name in modules:
+        yield __import__(module_name, globals_, None, (), 1)
+
+
+def _modules_path(path, files):
+    sys.path.insert(0, path)
+    try:
+        return [
+            __import__(name[:-3])
+            for name in files
+            if name.endswith(".py")
+        ]
+    finally:
+        del sys.path[0]
 
 
 def _get_classes(module):
@@ -240,3 +261,7 @@ def _get_classes(module):
             hasattr(cls, "pattern") and cls.__module__ == module.__name__
         )
     ]
+
+
+_cache = []
+_module_iter = _modules_internal()
