@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015-2021 Mike Fährmann
+# Copyright 2015-2023 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -9,8 +9,7 @@
 """Extractors for https://mangapark.net/"""
 
 from .common import ChapterExtractor, MangaExtractor
-from .. import text, exception
-import json
+from .. import text, util, exception
 import re
 
 
@@ -104,7 +103,7 @@ class MangaparkChapterExtractor(MangaparkBase, ChapterExtractor):
         return data
 
     def images(self, page):
-        data = json.loads(text.extract(page, "var _load_pages =", ";")[0])
+        data = util.json_loads(text.extr(page, "var _load_pages =", ";"))
         return [
             (text.urljoin(self.root, item["u"]), {
                 "width": text.parse_int(item["w"]),
@@ -121,8 +120,8 @@ class MangaparkMangaExtractor(MangaparkBase, MangaExtractor):
                r"(/manga/[^/?#]+)/?$")
     test = (
         ("https://mangapark.net/manga/aria", {
-            "url": "b8f7db2f581404753c4af37af66c049a41273b94",
-            "keyword": "2c0d28efaf84fcfe62932b6931ef3c3987cd48c0",
+            "url": "51c6d82aed5c3c78e0d3f980b09a998e6a2a83ee",
+            "keyword": "cabc60cf2efa82749d27ac92c495945961e4b73c",
         }),
         ("https://mangapark.me/manga/aria"),
         ("https://mangapark.com/manga/aria"),
@@ -136,10 +135,10 @@ class MangaparkMangaExtractor(MangaparkBase, MangaExtractor):
         results = []
         data = {"lang": "en", "language": "English"}
         data["manga"] = text.unescape(
-            text.extract(page, '<title>', ' Manga - ')[0])
+            text.extr(page, '<title>', ' Manga - '))
 
         for stream in page.split('<div id="stream_')[1:]:
-            data["stream"] = text.parse_int(text.extract(stream, '', '"')[0])
+            data["stream"] = text.parse_int(text.extr(stream, '', '"'))
 
             for chapter in text.extract_iter(stream, '<li ', '</li>'):
                 path  , pos = text.extract(chapter, 'href="', '"')
