@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2020-2021 Mike Fährmann
+# Copyright 2020-2022 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -26,17 +26,38 @@ class MoebooruExtractor(BooruExtractor):
     def _prepare(post):
         post["date"] = text.parse_timestamp(post["created_at"])
 
-    def _extended_tags(self, post):
-        url = "{}/post/show/{}".format(self.root, post["id"])
-        page = self.request(url).text
-        html = text.extract(page, '<ul id="tag-', '</ul>')[0]
-        if html:
-            tags = collections.defaultdict(list)
-            pattern = re.compile(r"tag-type-([^\"' ]+).*?[?;]tags=([^\"'+]+)")
-            for tag_type, tag_name in pattern.findall(html):
-                tags[tag_type].append(text.unquote(tag_name))
-            for key, value in tags.items():
-                post["tags_" + key] = " ".join(value)
+    def _html(self, post):
+        return self.request("{}/post/show/{}".format(
+            self.root, post["id"])).text
+
+    def _tags(self, post, page):
+        tag_container = text.extr(page, '<ul id="tag-', '</ul>')
+        if not tag_container:
+            return
+
+        tags = collections.defaultdict(list)
+        pattern = re.compile(r"tag-type-([^\"' ]+).*?[?;]tags=([^\"'+]+)")
+        for tag_type, tag_name in pattern.findall(tag_container):
+            tags[tag_type].append(text.unquote(tag_name))
+        for key, value in tags.items():
+            post["tags_" + key] = " ".join(value)
+
+    def _notes(self, post, page):
+        note_container = text.extr(page, 'id="note-container"', "<img ")
+        if not note_container:
+            return
+
+        post["notes"] = notes = []
+        for note in note_container.split('class="note-box"')[1:]:
+            extr = text.extract_from(note)
+            notes.append({
+                "width" : int(extr("width:", "p")),
+                "height": int(extr("height:", "p")),
+                "y"     : int(extr("top:", "p")),
+                "x"     : int(extr("left:", "p")),
+                "id"    : int(extr('id="note-body-', '"')),
+                "body"  : text.unescape(text.remove_html(extr(">", "</div>"))),
+            })
 
     def _pagination(self, url, params):
         params["page"] = self.page_start
@@ -54,20 +75,19 @@ class MoebooruExtractor(BooruExtractor):
 BASE_PATTERN = MoebooruExtractor.update({
     "yandere": {
         "root": "https://yande.re",
+        "pattern": r"yande\.re",
     },
     "konachan": {
         "root": "https://konachan.com",
         "pattern": r"konachan\.(?:com|net)",
     },
-    "hypnohub": {
-        "root": "https://hypnohub.net",
-    },
     "sakugabooru": {
         "root": "https://www.sakugabooru.com",
         "pattern": r"(?:www\.)?sakugabooru\.com",
     },
     "lolibooru": {
         "root": "https://lolibooru.moe",
+        "pattern": r"lolibooru\.moe",
     },
 })
 
@@ -97,10 +117,38 @@ class MoebooruPostExtractor(MoebooruExtractor):
                 "tags_general": str,
             },
         }),
-        ("https://konachan.net/post/show/205189"),
-        ("https://hypnohub.net/post/show/73964", {
-            "content": "02d5f5a8396b621a6efc04c5f8ef1b7225dfc6ee",
+        ("https://yande.re/post/show/993156", {
+            "content": "fed722bd90f48de41ec163692befc701056e2b1e",
+            "options": (("notes", True),),
+            "keyword": {
+                "notes": [
+                    {
+                        "id": 7096,
+                        "x" : 90,
+                        "y" : 626,
+                        "width" : 283,
+                        "height": 529,
+                        "body"  : "Please keep this as a secret for me!!",
+                    },
+                    {
+                        "id": 7095,
+                        "x" : 900,
+                        "y" : 438,
+                        "width" : 314,
+                        "height": 588,
+                        "body"  : "The facts that I love playing games",
+                    },
+                ],
+            },
         }),
+        ("https://lolibooru.moe/post/show/281305/", {
+            "content": "a331430223ffc5b23c31649102e7d49f52489b57",
+            "options": (("notes", True),),
+            "keyword": {
+                "notes": list,
+            },
+        }),
+        ("https://konachan.net/post/show/205189"),
         ("https://www.sakugabooru.com/post/show/125570"),
         ("https://lolibooru.moe/post/show/287835"),
     )
@@ -127,9 +175,6 @@ class MoebooruTagExtractor(MoebooruExtractor):
             "content": "838cfb815e31f48160855435655ddf7bfc4ecb8d",
         }),
         ("https://konachan.net/post?tags=patata"),
-        ("https://hypnohub.net/post?tags=gonoike_biwa", {
-            "url": "072330c34a1e773d0cafd00e64b8060d34b078b6",
-        }),
         ("https://www.sakugabooru.com/post?tags=nichijou"),
         ("https://lolibooru.moe/post?tags=ruu_%28tksymkw%29"),
     )
@@ -160,9 +205,6 @@ class MoebooruPoolExtractor(MoebooruExtractor):
             "content": "cf0546e38a93c2c510a478f8744e60687b7a8426",
         }),
         ("https://konachan.net/pool/show/95"),
-        ("https://hypnohub.net/pool/show/61", {
-            "url": "fd74991c8729e77acd3c35eb6ddc4128ff445adf",
-        }),
         ("https://www.sakugabooru.com/pool/show/54"),
         ("https://lolibooru.moe/pool/show/239"),
     )
@@ -195,10 +237,6 @@ class MoebooruPopularExtractor(MoebooruExtractor):
         }),
         ("https://konachan.com/post/popular_recent"),
         ("https://konachan.net/post/popular_recent"),
-        ("https://hypnohub.net/post/popular_by_month?month=6&year=2014", {
-            "count": 20,
-        }),
-        ("https://hypnohub.net/post/popular_recent"),
         ("https://www.sakugabooru.com/post/popular_recent"),
         ("https://lolibooru.moe/post/popular_recent"),
     )
