@@ -93,6 +93,11 @@ class NitterExtractor(BaseExtractor):
                                 "filename" : name.rpartition(".")[0],
                                 "extension": "mp4",
                             })
+
+                        for url in text.extract_iter(
+                                attachments, '<source src="', '"'):
+                            append(text.nameext_from_url(url, {"url": url}))
+
             else:
                 files = ()
             tweet["count"] = len(files)
@@ -157,7 +162,11 @@ class NitterExtractor(BaseExtractor):
         banner = extr('class="profile-banner"><a href="', '"')
 
         try:
-            uid = banner.split("%2F")[4]
+            if "/enc/" in banner:
+                uid = binascii.a2b_base64(banner.rpartition(
+                    "/")[2]).decode().split("/")[4]
+            else:
+                uid = banner.split("%2F")[4]
         except Exception:
             uid = 0
 
@@ -297,7 +306,10 @@ class NitterTweetsExtractor(NitterExtractor):
                        r"/media%2FCGMNYZvW0AIVoom\.jpg",
             "range": "1",
         }),
-        ("https://nitter.1d4.us/supernaturepics"),
+        ("https://nitter.1d4.us/supernaturepics", {
+            "range": "1",
+            "keyword": {"user": {"id": "2976459548"}},
+        }),
         ("https://nitter.kavin.rocks/id:2976459548"),
         ("https://nitter.unixfox.eu/supernaturepics"),
     )
