@@ -596,6 +596,9 @@ class PixivSearchExtractor(PixivExtractor):
         sort_map = {
             "date": "date_asc",
             "date_d": "date_desc",
+            "popular_d": "popular_desc",
+            "popular_male_d": "popular_male_desc",
+            "popular_female_d": "popular_female_desc",
         }
         try:
             self.sort = sort = sort_map[sort]
@@ -670,7 +673,7 @@ class PixivPixivisionExtractor(PixivExtractor):
 
     def works(self):
         return (
-            self.api.illust_detail(illust_id)
+            self.api.illust_detail(illust_id.partition("?")[0])
             for illust_id in util.unique_sequence(text.extract_iter(
                 self.page, '<a href="https://www.pixiv.net/en/artworks/', '"'))
         )
