@@ -87,6 +87,7 @@ class MetadataPP(PostProcessor):
         self.omode = options.get("open", omode)
         self.encoding = options.get("encoding", "utf-8")
         self.private = options.get("private", False)
+        self.skip = options.get("skip", False)
 
     def run(self, pathfmt):
         archive = self.archive
@@ -96,6 +97,9 @@ class MetadataPP(PostProcessor):
         directory = self._directory(pathfmt)
         path = directory + self._filename(pathfmt)
 
+        if self.skip and os.path.exists(path):
+            return
+
         try:
             with open(path, self.omode, encoding=self.encoding) as fp:
                 self.write(fp, pathfmt.kwdict)
@@ -120,10 +124,8 @@ class MetadataPP(PostProcessor):
         for key, func in self.fields.items():
             obj = kwdict
             try:
-                while "[" in key:
-                    name, _, key = key.partition("[")
-                    obj = obj[name]
-                    key = key.rstrip("]")
+                if "[" in key:
+                    obj, key = _traverse(obj, key)
                 obj[key] = func(kwdict)
             except Exception:
                 pass
@@ -133,10 +135,8 @@ class MetadataPP(PostProcessor):
         for key in self.fields:
             obj = kwdict
             try:
-                while "[" in key:
-                    name, _, key = key.partition("[")
-                    obj = obj[name]
-                    key = key.rstrip("]")
+                if "[" in key:
+                    obj, key = _traverse(obj, key)
                 del obj[key]
             except Exception:
                 pass
@@ -210,4 +210,15 @@ class MetadataPP(PostProcessor):
         )
 
 
+def _traverse(obj, key):
+    name, _, key = key.partition("[")
+    obj = obj[name]
+
+    while "[" in key:
+        name, _, key = key.partition("[")
+        obj = obj[name.strip("\"']")]
+
+    return obj, key.strip("\"']")
+
+
 __postprocessor__ = MetadataPP
