@@ -388,50 +388,94 @@ class MetadataTest(BasePostprocessorTest):
 """)
 
     def test_metadata_modify(self):
-        kwdict = {"foo": 0, "bar": {"bax": 1, "bay": 2, "baz": 3}}
+        kwdict = {"foo": 0, "bar": {"bax": 1, "bay": 2, "baz": 3, "ba2": {}}}
         self._create({
             "mode": "modify",
             "fields": {
-                "foo"     : "{filename}-{foo!s}",
-                "foo2"    : "\fE bar['bax'] + 122",
-                "bar[baz]": "{_now}",
-                "bar[ba2]": "test",
+                "foo"          : "{filename}-{foo!s}",
+                "foo2"         : "\fE bar['bax'] + 122",
+                "bar[\"baz\"]" : "{_now}",
+                "bar['ba2'][a]": "test",
             },
         }, kwdict)
-        pdict = self.pathfmt.kwdict
 
+        pdict = self.pathfmt.kwdict
         self.assertIsNot(kwdict, pdict)
         self.assertEqual(pdict["foo"], kwdict["foo"])
         self.assertEqual(pdict["bar"], kwdict["bar"])
 
         self._trigger()
 
-        self.assertEqual(pdict["foo"]       , "file-0")
-        self.assertEqual(pdict["foo2"]      , 123)
-        self.assertEqual(pdict["bar"]["ba2"], "test")
+        self.assertEqual(pdict["foo"] , "file-0")
+        self.assertEqual(pdict["foo2"], 123)
+        self.assertEqual(pdict["bar"]["ba2"]["a"], "test")
         self.assertIsInstance(pdict["bar"]["baz"], datetime)
 
     def test_metadata_delete(self):
-        kwdict = {"foo": 0, "bar": {"bax": 1, "bay": 2, "baz": 3}}
-        self._create({"mode": "delete", "fields": ["foo", "bar[baz]"]}, kwdict)
-        pdict = self.pathfmt.kwdict
+        kwdict = {
+            "foo": 0,
+            "bar": {
+                "bax": 1,
+                "bay": 2,
+                "baz": {"a": 3, "b": 4},
+            },
+        }
+        self._create({
+            "mode": "delete",
+            "fields": ["foo", "bar['bax']", "bar[\"baz\"][a]"],
+        }, kwdict)
 
+        pdict = self.pathfmt.kwdict
         self.assertIsNot(kwdict, pdict)
+
         self.assertEqual(pdict["foo"], kwdict["foo"])
         self.assertEqual(pdict["bar"], kwdict["bar"])
 
-        del kwdict["foo"]
-        del kwdict["bar"]["baz"]
+        self._trigger()
 
+        self.assertNotIn("foo", pdict)
+        self.assertNotIn("bax", pdict["bar"])
+        self.assertNotIn("a", pdict["bar"]["baz"])
+
+        # no errors for deleted/undefined fields
         self._trigger()
         self.assertNotIn("foo", pdict)
-        self.assertNotIn("baz", pdict["bar"])
-        self.assertEqual(kwdict["bar"], pdict["bar"])
+        self.assertNotIn("bax", pdict["bar"])
+        self.assertNotIn("a", pdict["bar"]["baz"])
 
-        self._trigger()
-        self.assertNotIn("foo", pdict)
-        self.assertNotIn("baz", pdict["bar"])
-        self.assertEqual(kwdict["bar"], pdict["bar"])
+    def test_metadata_option_skip(self):
+        self._create({"skip": True})
+
+        with patch("builtins.open", mock_open()) as m, \
+                patch("os.path.exists") as e:
+            e.return_value = True
+            self._trigger()
+
+        self.assertTrue(e.called)
+        self.assertTrue(not m.called)
+        self.assertTrue(not len(self._output(m)))
+
+        with patch("builtins.open", mock_open()) as m, \
+                patch("os.path.exists") as e:
+            e.return_value = False
+            self._trigger()
+
+        self.assertTrue(e.called)
+        self.assertTrue(m.called)
+        self.assertGreater(len(self._output(m)), 0)
+
+        path = self.pathfmt.realdirectory + "file.ext.json"
+        m.assert_called_once_with(path, "w", encoding="utf-8")
+
+    def test_metadata_option_skip_false(self):
+        self._create({"skip": False})
+
+        with patch("builtins.open", mock_open()) as m, \
+                patch("os.path.exists") as e:
+            self._trigger()
+
+        self.assertTrue(not e.called)
+        self.assertTrue(m.called)
 
     @staticmethod
     def _output(mock):
